@@ -1,6 +1,6 @@
 import inspect
 
-from ...utils import call_main
+from ...utils import run_main
 
 
 def add_parser(sub_parser, raw):
@@ -34,4 +34,4 @@ def add_parser(sub_parser, raw):
 def run(_):
     # pylint: disable=import-outside-toplevel
     from .... import git
-    return call_main(git.get_status, [], print_raw=True)
+    return run_main(git.get_status, print)
